==> huaweicloudsdkdataartsstudio-3.1.140-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/public_network_access.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PublicNetworkAccess:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'result': 'DiagnoseResult',
        'public_network_info': 'list[PublicNetworkStatus]'
    }

    attribute_map = {
        'result': 'result',
        'public_network_info': 'public_network_info'
    }

    def __init__(self, result=None, public_network_info=None):
        """PublicNetworkAccess

        The model defined in huaweicloud sdk

        :param result: 
        :type result: :class:`huaweicloudsdkdataartsstudio.v1.DiagnoseResult`
        :param public_network_info: kerberos信息
        :type public_network_info: list[:class:`huaweicloudsdkdataartsstudio.v1.PublicNetworkStatus`]
        """
        
        

        self._result = None
        self._public_network_info = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if public_network_info is not None:
            self.public_network_info = public_network_info

    @property
    def result(self):
        """Gets the result of this PublicNetworkAccess.

        :return: The result of this PublicNetworkAccess.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.DiagnoseResult`
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this PublicNetworkAccess.

        :param result: The result of this PublicNetworkAccess.
        :type result: :class:`huaweicloudsdkdataartsstudio.v1.DiagnoseResult`
        """
        self._result = result

    @property
    def public_network_info(self):
        """Gets the public_network_info of this PublicNetworkAccess.

        kerberos信息

        :return: The public_network_info of this PublicNetworkAccess.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.PublicNetworkStatus`]
        """
        return self._public_network_info

    @public_network_info.setter
    def public_network_info(self, public_network_info):
        """Sets the public_network_info of this PublicNetworkAccess.

        kerberos信息

        :param public_network_info: The public_network_info of this PublicNetworkAccess.
        :type public_network_info: list[:class:`huaweicloudsdkdataartsstudio.v1.PublicNetworkStatus`]
        """
        self._public_network_info = public_network_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicNetworkAccess):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/public_network_access.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PublicNetworkAccess:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'result': 'DiagnoseResult',
        'public_network_info': 'list[PublicNetworkStatus]'
    }

    attribute_map = {
        'result': 'result',
        'public_network_info': 'public_network_info'
    }

    def __init__(self, result=None, public_network_info=None):
        r"""PublicNetworkAccess

        The model defined in huaweicloud sdk

        :param result: 
        :type result: :class:`huaweicloudsdkdataartsstudio.v1.DiagnoseResult`
        :param public_network_info: kerberos信息
        :type public_network_info: list[:class:`huaweicloudsdkdataartsstudio.v1.PublicNetworkStatus`]
        """
        
        

        self._result = None
        self._public_network_info = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if public_network_info is not None:
            self.public_network_info = public_network_info

    @property
    def result(self):
        r"""Gets the result of this PublicNetworkAccess.

        :return: The result of this PublicNetworkAccess.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.DiagnoseResult`
        """
        return self._result

    @result.setter
    def result(self, result):
        r"""Sets the result of this PublicNetworkAccess.

        :param result: The result of this PublicNetworkAccess.
        :type result: :class:`huaweicloudsdkdataartsstudio.v1.DiagnoseResult`
        """
        self._result = result

    @property
    def public_network_info(self):
        r"""Gets the public_network_info of this PublicNetworkAccess.

        kerberos信息

        :return: The public_network_info of this PublicNetworkAccess.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.PublicNetworkStatus`]
        """
        return self._public_network_info

    @public_network_info.setter
    def public_network_info(self, public_network_info):
        r"""Sets the public_network_info of this PublicNetworkAccess.

        kerberos信息

        :param public_network_info: The public_network_info of this PublicNetworkAccess.
        :type public_network_info: list[:class:`huaweicloudsdkdataartsstudio.v1.PublicNetworkStatus`]
        """
        self._public_network_info = public_network_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicNetworkAccess):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
